pub fn apply_palette(indexed: &[u8], palette: &[u32], target: &mut [u32])
Apply a palette to indexed pixel data, producing RGBA output. This is used when we’ve cached the indexed pixels and need to apply a new palette.